homology — GDA Toolbox v1.0 Manual

# homology

This module defines the the basic objects for persistence diagrams:

> - `PersDiag`

## Copyright

- This file is part of https://github.com/geomdata/gda-public/
- 2015, 2016, 2017 by Geometric Data Analytics, Inc. (http://geomdata.com)
- AGPL license. See LICENSE or https://github.com/geomdata/gda-public/blob/master/LICENSE

Classes

`PersDiag`(birth_index, death_index, …) | Persistence Diagrams and related merge-tree information.

### Table of Contents

- homology
  - Copyright

#### Previous topic

All Modules, Classes, and Methods

#### Next topic

homology.dim0